<!-- generated by QuantStats for Python -->
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>Tearsheet (generated by QuantStats)</title>
    <meta name="robots" content="noindex, nofollow">
    <link rel="shortcut icon" href="https://qtpylib.io/favicon.ico" type="image/x-icon">
    <style>
    body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;margin:30px}body,p,table,td,th{font:13px/1.4 Arial,sans-serif}.container{max-width:960px;margin:auto}img,svg{width:100%}h1,h2,h3,h4{font-weight:400;margin:0}h1 dt{display:inline;margin-left:10px;font-size:14px}h3{margin-bottom:10px;font-weight:700}h4{color:grey}h4 a{color:#09c;text-decoration:none}h4 a:hover{color:#069;text-decoration:underline}hr{margin:25px 0 40px;height:0;border:0;border-top:1px solid #ccc}#left{width:620px;margin-right:18px;margin-top:-1.2rem;float:left}#right{width:320px;float:right}#left svg{margin:-1.5rem 0}#monthly_heatmap{overflow:hidden}#monthly_heatmap svg{margin:-1.5rem 0}table{margin:0 0 40px;border:0;border-spacing:0;width:100%}table td,table th{text-align:right;padding:4px 5px 3px 5px}table th{text-align:right;padding:6px 5px 5px 5px}table td:first-of-type,table th:first-of-type{text-align:left;padding-left:2px}table td:last-of-type,table th:last-of-type{text-align:right;padding-right:2px}td hr{margin:5px 0}table th{font-weight:400}table thead th{font-weight:700;background:#eee}#eoy table td:after{content:"%"}#eoy table td:first-of-type:after,#eoy table td:last-of-type:after,#eoy table td:nth-of-type(4):after{content:""}#eoy table th{text-align:right}#eoy table th:first-of-type{text-align:left}#eoy table td:after{content:"%"}#eoy table td:first-of-type:after,#eoy table td:last-of-type:after{content:""}#ddinfo table td:nth-of-type(3):after{content:"%"}#ddinfo table th{text-align:right}#ddinfo table td:first-of-type,#ddinfo table td:nth-of-type(2),#ddinfo table th:first-of-type,#ddinfo table th:nth-of-type(2){text-align:left}#ddinfo table td:nth-of-type(3):after{content:"%"}
    @media print{hr{margin:25px 0}body{margin:0}.container{max-width:100%;margin:0}#left{width:55%;margin:0}#left svg{margin:0 0 -10%}#left svg:first-of-type{margin-top:-30%}#right{margin:0;width:45%}}
    </style>
</head>

<body onload="save()">

    <div class="container">

        <h1>{{title}} <dt>{{date_range}}</dt></h1>
        <h4>{{benchmark_title}} Generated by <a href="http://quantstats.io" target="quantstats">QuantStats</a> (v. {{v}})</h4>
        <hr>

        <div id="left">

            <div>
                {{returns}}
            </div>

            <div id="log_returns">{{log_returns}}</div>
            <div id="vol_returns">{{vol_returns}}</div>
            <div id="eoy_returns">{{eoy_returns}}</div>
            <div id="monthly_dist">{{monthly_dist}}</div>
            <div id="daily_returns">{{daily_returns}}</div>
            <div id="rolling_beta">{{rolling_beta}}</div>
            <div id="rolling_vol">{{rolling_vol}}</div>
            <div id="rolling_sharpe">{{rolling_sharpe}}</div>
            <div id="rolling_sortino">{{rolling_sortino}}</div>
            <div id="dd_periods">{{dd_periods}}</div>
            <div id="dd_plot">{{dd_plot}}</div>
            <div id="monthly_heatmap">{{monthly_heatmap}}</div>
            <div id="returns_dist">{{returns_dist}}</div>

        </div>

        <div id="right">
            <h3>Key Performance Metrics</h3>
            {{metrics}}

            <div id="eoy">{{eoy_title}}
                {{eoy_table}}</div>

            <div id="ddinfo">
                <h3>Worst 10 Drawdowns</h3>
                {{dd_info}}
            </div>
        </div>

    </div>
    <style>*{white-space:auto !important;}</style>
</body>
</html>
